@@ -24,13 +24,14 @@
 #ifndef _LIBQMI_GLIB_QMI_ENUMS_DMS_H_
 #define _LIBQMI_GLIB_QMI_ENUMS_DMS_H_
 
+#include <glib.h>
+
 #if !defined (__LIBQMI_GLIB_H_INSIDE__) && !defined (LIBQMI_GLIB_COMPILATION)
 #error "Only <libqmi-glib.h> can be included directly."
 #endif
 
 /**
  * SECTION: qmi-enums-dms
- * @title: DMS enumerations and flags
  *
  * This section defines enumerations and flags used in the DMS service
  * interface.
@@ -51,7 +52,7 @@
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_DATA_SERVICE_CAPABILITY_NONE                   = 0,
     QMI_DMS_DATA_SERVICE_CAPABILITY_CS                     = 1,
     QMI_DMS_DATA_SERVICE_CAPABILITY_PS                     = 2,
@@ -59,12 +60,6 @@ typedef enum {
     QMI_DMS_DATA_SERVICE_CAPABILITY_NON_SIMULTANEOUS_CS_PS = 4
 } QmiDmsDataServiceCapability;
 
-/**
- * qmi_dms_data_service_capability_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiDmsSimCapability:
  * @QMI_DMS_SIM_CAPABILITY_NOT_SUPPORTED: SIM not supported.
@@ -74,17 +69,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_SIM_CAPABILITY_NOT_SUPPORTED = 1,
     QMI_DMS_SIM_CAPABILITY_SUPPORTED     = 2
 } QmiDmsSimCapability;
 
-/**
- * qmi_dms_sim_capability_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiDmsRadioInterface:
  * @QMI_DMS_RADIO_INTERFACE_CDMA20001X: CDMA2000 1x.
@@ -92,25 +81,21 @@ typedef enum {
  * @QMI_DMS_RADIO_INTERFACE_GSM: GSM.
  * @QMI_DMS_RADIO_INTERFACE_UMTS: UMTS.
  * @QMI_DMS_RADIO_INTERFACE_LTE: LTE.
+ * @QMI_DMS_RADIO_INTERFACE_5GNR: 5G NR. Since 1.26.
  *
  * Radio interface type.
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_RADIO_INTERFACE_CDMA20001X = 1,
     QMI_DMS_RADIO_INTERFACE_EVDO       = 2,
     QMI_DMS_RADIO_INTERFACE_GSM        = 4,
     QMI_DMS_RADIO_INTERFACE_UMTS       = 5,
-    QMI_DMS_RADIO_INTERFACE_LTE        = 8
+    QMI_DMS_RADIO_INTERFACE_LTE        = 8,
+    QMI_DMS_RADIO_INTERFACE_5GNR       = 10,
 } QmiDmsRadioInterface;
 
-/**
- * qmi_dms_radio_interface_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Get Power State' message */
 
@@ -136,19 +121,13 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_POWER_STATE_EXTERNAL_SOURCE   = 1 << 0,
     QMI_DMS_POWER_STATE_BATTERY_CONNECTED = 1 << 1,
     QMI_DMS_POWER_STATE_BATTERY_CHARGING  = 1 << 2,
     QMI_DMS_POWER_STATE_FAULT             = 1 << 3,
 } QmiDmsPowerState;
 
-/**
- * qmi_dms_power_state_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS UIM Set PIN Protection' message */
 
@@ -161,17 +140,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_UIM_PIN_ID_PIN  = 1,
     QMI_DMS_UIM_PIN_ID_PIN2 = 2
 } QmiDmsUimPinId;
 
-/**
- * qmi_dms_uim_pin_id_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS UIM Get PIN Status' message */
 
@@ -190,7 +163,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_UIM_PIN_STATUS_NOT_INITIALIZED      = 0,
     QMI_DMS_UIM_PIN_STATUS_ENABLED_NOT_VERIFIED = 1,
     QMI_DMS_UIM_PIN_STATUS_ENABLED_VERIFIED     = 2,
@@ -201,12 +174,6 @@ typedef enum {
     QMI_DMS_UIM_PIN_STATUS_CHANGED              = 7,
 } QmiDmsUimPinStatus;
 
-/**
- * qmi_dms_uim_pin_status_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Get Operating Mode' message */
 
@@ -226,7 +193,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_OPERATING_MODE_ONLINE                = 0,
     QMI_DMS_OPERATING_MODE_LOW_POWER             = 1,
     QMI_DMS_OPERATING_MODE_FACTORY_TEST          = 2,
@@ -238,12 +205,6 @@ typedef enum {
     QMI_DMS_OPERATING_MODE_UNKNOWN               = 0xFF
 } QmiDmsOperatingMode;
 
-/**
- * qmi_dms_operating_mode_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiDmsOfflineReason:
  * @QMI_DMS_OFFLINE_REASON_HOST_IMAGE_MISCONFIGURATION: Host image misconfiguration.
@@ -255,19 +216,13 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_OFFLINE_REASON_HOST_IMAGE_MISCONFIGURATION = 1 << 0,
     QMI_DMS_OFFLINE_REASON_PRI_IMAGE_MISCONFIGURATION  = 1 << 1,
     QMI_DMS_OFFLINE_REASON_PRI_VERSION_INCOMPATIBLE    = 1 << 2,
     QMI_DMS_OFFLINE_REASON_DEVICE_MEMORY_FULL          = 1 << 3
 } QmiDmsOfflineReason;
 
-/**
- * qmi_dms_offline_reason_build_string_from_mask:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Get Time' message */
 
@@ -281,18 +236,12 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_TIME_SOURCE_DEVICE        = 0,
     QMI_DMS_TIME_SOURCE_CDMA_NETWORK  = 1,
     QMI_DMS_TIME_SOURCE_HDR_NETWORK   = 2,
 } QmiDmsTimeSource;
 
-/**
- * qmi_dms_time_source_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Get Activation State' message */
 
@@ -314,7 +263,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_ACTIVATION_STATE_NOT_ACTIVATED       = 0x00,
     QMI_DMS_ACTIVATION_STATE_ACTIVATED           = 0x01,
     QMI_DMS_ACTIVATION_STATE_CONNECTING          = 0x02,
@@ -328,12 +277,6 @@ typedef enum {
     QMI_DMS_ACTIVATION_STATE_OTASP_COMMITED      = 0x0A
 } QmiDmsActivationState;
 
-/**
- * qmi_dms_activation_state_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS UIM Get CK Status' message */
 
@@ -349,7 +292,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_UIM_FACILITY_PN = 0,
     QMI_DMS_UIM_FACILITY_PU = 1,
     QMI_DMS_UIM_FACILITY_PP = 2,
@@ -357,12 +300,6 @@ typedef enum {
     QMI_DMS_UIM_FACILITY_PF = 4
 } QmiDmsUimFacility;
 
-/**
- * qmi_dms_uim_facility_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiDmsUimFacilityState:
  * @QMI_DMS_UIM_FACILITY_STATE_DEACTIVATED: Facility is deactivated.
@@ -373,18 +310,12 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_UIM_FACILITY_STATE_DEACTIVATED = 0,
     QMI_DMS_UIM_FACILITY_STATE_ACTIVATED   = 1,
     QMI_DMS_UIM_FACILITY_STATE_BLOCKED     = 2
 } QmiDmsUimFacilityState;
 
-/**
- * qmi_dms_uim_facility_state_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS UIM Get State' message */
 
@@ -400,7 +331,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_UIM_STATE_INITIALIZATION_COMPLETED = 0x00,
     QMI_DMS_UIM_STATE_LOCKED_OR_FAILED         = 0x01,
     QMI_DMS_UIM_STATE_NOT_PRESENT              = 0x02,
@@ -408,12 +339,6 @@ typedef enum {
     QMI_DMS_UIM_STATE_UNKNOWN                  = 0xFF
 } QmiDmsUimState;
 
-/**
- * qmi_dms_uim_state_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Set Time' message */
 
@@ -425,16 +350,10 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_TIME_REFERENCE_TYPE_USER = 0
 } QmiDmsTimeReferenceType;
 
-/**
- * qmi_dms_time_reference_type_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Get Firmware Preference' message */
 
@@ -447,17 +366,11 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_FIRMWARE_IMAGE_TYPE_MODEM = 0,
     QMI_DMS_FIRMWARE_IMAGE_TYPE_PRI   = 1
 } QmiDmsFirmwareImageType;
 
-/**
- * qmi_dms_firmware_image_type_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS Get Boot Image Download Mode' message */
 
@@ -470,16 +383,27 @@ typedef enum {
  *
  * Since: 1.18
  */
-typedef enum {
+typedef enum { /*< since=1.18 >*/
     QMI_DMS_BOOT_IMAGE_DOWNLOAD_MODE_NORMAL            = 0,
     QMI_DMS_BOOT_IMAGE_DOWNLOAD_MODE_BOOT_AND_RECOVERY = 1,
 } QmiDmsBootImageDownloadMode;
 
+/*****************************************************************************/
+/* Helper enums for the 'QMI DMS Get MAC Address' message */
+
 /**
- * qmi_dms_boot_image_download_mode_get_string:
+ * QmiDmsMacType:
+ * @QMI_DMS_MAC_TYPE_WLAN: WLAN MAC address.
+ * @QMI_DMS_MAC_TYPE_BT: Bluetooth MAC address.
  *
- * Since: 1.18
+ * Specifies the device from which the MAC address should be queried.
+ *
+ * Since: 1.26
  */
+typedef enum { /*< since=1.26 >*/
+    QMI_DMS_MAC_TYPE_WLAN = 0,
+    QMI_DMS_MAC_TYPE_BT = 1,
+} QmiDmsMacType;
 
 /*****************************************************************************/
 /* Helper enums for the 'QMI DMS HP Change Device Mode' message */
@@ -492,14 +416,118 @@ typedef enum {
  *
  * Since: 1.18
  */
-typedef enum {
+typedef enum { /*< since=1.18 >*/
     QMI_DMS_HP_DEVICE_MODE_FASTBOOT = 5,
 } QmiDmsHpDeviceMode;
 
+/*****************************************************************************/
+/* Helper enums for the 'QMI DMS Swi Get USB Composition' message */
+
 /**
- * qmi_dms_hp_device_mode_get_string:
+ * QmiDmsSwiUsbComposition:
+ * @QMI_DMS_SWI_USB_COMPOSITION_UNKNOWN: Unknown.
+ * @QMI_DMS_SWI_USB_COMPOSITION_0: HIP, DM, NMEA, AT, MDM1, MDM2, MDM3, MS.
+ * @QMI_DMS_SWI_USB_COMPOSITION_1: HIP, DM, NMEA, AT, MDM1, MS.
+ * @QMI_DMS_SWI_USB_COMPOSITION_2: HIP, DM, NMEA, AT, NIC1, MS.
+ * @QMI_DMS_SWI_USB_COMPOSITION_3: HIP, DM, NMEA, AT, MDM1, NIC1, MS.
+ * @QMI_DMS_SWI_USB_COMPOSITION_4: HIP, DM, NMEA, AT, NIC1, NIC2, NIC3, MS.
+ * @QMI_DMS_SWI_USB_COMPOSITION_5: HIP, DM, NMEA, AT, ECM1, MS.
+ * @QMI_DMS_SWI_USB_COMPOSITION_6: DM, NMEA, AT, QMI.
+ * @QMI_DMS_SWI_USB_COMPOSITION_7: DM, NMEA, AT, RMNET1, RMNET2, RMNET3.
+ * @QMI_DMS_SWI_USB_COMPOSITION_8: DM, NMEA, AT, MBIM.
+ * @QMI_DMS_SWI_USB_COMPOSITION_9: MBIM.
+ * @QMI_DMS_SWI_USB_COMPOSITION_10: NMEA, MBIM.
+ * @QMI_DMS_SWI_USB_COMPOSITION_11: DM, MBIM.
+ * @QMI_DMS_SWI_USB_COMPOSITION_12: DM, NMEA, MBIM.
+ * @QMI_DMS_SWI_USB_COMPOSITION_13: Dual configuration: USB composition 6 and USB composition 8.
+ * @QMI_DMS_SWI_USB_COMPOSITION_14: Dual configuration: USB composition 6 and USB composition 9.
+ * @QMI_DMS_SWI_USB_COMPOSITION_15: Dual configuration: USB composition 6 and USB composition 10.
+ * @QMI_DMS_SWI_USB_COMPOSITION_16: Dual configuration: USB composition 6 and USB composition 11.
+ * @QMI_DMS_SWI_USB_COMPOSITION_17: Dual configuration: USB composition 6 and USB composition 12.
+ * @QMI_DMS_SWI_USB_COMPOSITION_18: Dual configuration: USB composition 7 and USB composition 8.
+ * @QMI_DMS_SWI_USB_COMPOSITION_19: Dual configuration: USB composition 7 and USB composition 9.
+ * @QMI_DMS_SWI_USB_COMPOSITION_20: Dual configuration: USB composition 7 and USB composition 10.
+ * @QMI_DMS_SWI_USB_COMPOSITION_21: Dual configuration: USB composition 7 and USB composition 11.
+ * @QMI_DMS_SWI_USB_COMPOSITION_22: Dual configuration: USB composition 7 and USB composition 12.
  *
- * Since: 1.18
+ * Sierra Wireless USB composition modes.
+ *
+ * Since: 1.20
  */
+typedef enum { /*< since=1.20 >*/
+    QMI_DMS_SWI_USB_COMPOSITION_UNKNOWN = -1,
+    QMI_DMS_SWI_USB_COMPOSITION_0  =  0,
+    QMI_DMS_SWI_USB_COMPOSITION_1  =  1,
+    QMI_DMS_SWI_USB_COMPOSITION_2  =  2,
+    QMI_DMS_SWI_USB_COMPOSITION_3  =  3,
+    QMI_DMS_SWI_USB_COMPOSITION_4  =  4,
+    QMI_DMS_SWI_USB_COMPOSITION_5  =  5,
+    QMI_DMS_SWI_USB_COMPOSITION_6  =  6,
+    QMI_DMS_SWI_USB_COMPOSITION_7  =  7,
+    QMI_DMS_SWI_USB_COMPOSITION_8  =  8,
+    QMI_DMS_SWI_USB_COMPOSITION_9  =  9,
+    QMI_DMS_SWI_USB_COMPOSITION_10 = 10,
+    QMI_DMS_SWI_USB_COMPOSITION_11 = 11,
+    QMI_DMS_SWI_USB_COMPOSITION_12 = 12,
+    QMI_DMS_SWI_USB_COMPOSITION_13 = 13,
+    QMI_DMS_SWI_USB_COMPOSITION_14 = 14,
+    QMI_DMS_SWI_USB_COMPOSITION_15 = 15,
+    QMI_DMS_SWI_USB_COMPOSITION_16 = 16,
+    QMI_DMS_SWI_USB_COMPOSITION_17 = 17,
+    QMI_DMS_SWI_USB_COMPOSITION_18 = 18,
+    QMI_DMS_SWI_USB_COMPOSITION_19 = 19,
+    QMI_DMS_SWI_USB_COMPOSITION_20 = 20,
+    QMI_DMS_SWI_USB_COMPOSITION_21 = 21,
+    QMI_DMS_SWI_USB_COMPOSITION_22 = 22,
+} QmiDmsSwiUsbComposition;
+
+/**
+ * qmi_dms_swi_usb_composition_get_description:
+ * @value: a #QmiDmsSwiUsbComposition.
+ *
+ * Gets a text description of the Sierra Wireless USB composition.
+ *
+ * Since: 1.20
+ * Returns: a string.
+ */
+const gchar *qmi_dms_swi_usb_composition_get_description (QmiDmsSwiUsbComposition value);
+
+/*****************************************************************************/
+/* Helper enums for the 'QMI DMS Foxconn Change Device Mode' message */
+
+/**
+ * QmiDmsFoxconnDeviceMode:
+ * @QMI_DMS_FOXCONN_DEVICE_MODE_UNKNOWN: Unknown mode.
+ * @QMI_DMS_FOXCONN_DEVICE_MODE_FASTBOOT_ONLINE: Fastboot download mode for full partition files.
+ * @QMI_DMS_FOXCONN_DEVICE_MODE_FASTBOOT_OTA: Fastboot download mode for OTA files.
+ *
+ * Foxconn specific device modes.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    QMI_DMS_FOXCONN_DEVICE_MODE_UNKNOWN         = 0,
+    QMI_DMS_FOXCONN_DEVICE_MODE_FASTBOOT_ONLINE = 0x05,
+    QMI_DMS_FOXCONN_DEVICE_MODE_FASTBOOT_OTA    = 0x0A,
+} QmiDmsFoxconnDeviceMode;
+
+/*****************************************************************************/
+/* Helper enums for the 'QMI DMS Foxconn Get Firmware Version' message */
+
+/**
+ * QmiDmsFoxconnFirmwareVersionType:
+ * @QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_FIRMWARE_MCFG: E.g. T77W968.F0.0.0.2.3.GC.004.
+ * @QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_FIRMWARE_MCFG_APPS: E.g. T77W968.F0.0.0.2.3.GC.004.011.
+ * @QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_APPS: E.g. 011.
+ *
+ * Foxconn specific firmware version types.
+ *
+ * Since: 1.26
+ */
+typedef enum { /*< since=1.26 >*/
+    QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_FIRMWARE_MCFG      = 0x00,
+    QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_FIRMWARE_MCFG_APPS = 0x01,
+    QMI_DMS_FOXCONN_FIRMWARE_VERSION_TYPE_APPS               = 0x02,
+} QmiDmsFoxconnFirmwareVersionType;
 
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_DMS_H_ */
