@@ -22,7 +22,7 @@
 
 #include <glib.h>
 #include "qmi-enums-nas.h"
-#include "qmi-utils-private.h"
+#include "qmi-helpers.h"
 
 gchar *
 qmi_nas_read_string_from_plmn_encoded_array (QmiNasPlmnEncodingScheme  encoding,
@@ -30,9 +30,9 @@ qmi_nas_read_string_from_plmn_encoded_array (QmiNasPlmnEncodingScheme  encoding,
 {
     switch (encoding) {
     case QMI_NAS_PLMN_ENCODING_SCHEME_GSM:
-      return __qmi_string_utf8_from_gsm7 ((const guint8 *)array->data, array->len);
+      return qmi_helpers_string_utf8_from_gsm7 ((const guint8 *)array->data, array->len);
     case QMI_NAS_PLMN_ENCODING_SCHEME_UCS2LE:
-        return __qmi_string_utf8_from_ucs2le ((const guint8 *)array->data, array->len);
+        return qmi_helpers_string_utf8_from_ucs2le ((const guint8 *)array->data, array->len);
     default:
         return NULL;
     }
@@ -49,9 +49,9 @@ qmi_nas_read_string_from_network_description_encoded_array (QmiNasNetworkDescrip
                 g_strndup ((const gchar *)array->data, array->len) :
                 NULL);
     case QMI_NAS_NETWORK_DESCRIPTION_ENCODING_GSM:
-        return __qmi_string_utf8_from_gsm7 ((const guint8 *)array->data, array->len);
+        return qmi_helpers_string_utf8_from_gsm7 ((const guint8 *)array->data, array->len);
     case QMI_NAS_NETWORK_DESCRIPTION_ENCODING_UNICODE:
-        return __qmi_string_utf8_from_ucs2le ((const guint8 *)array->data, array->len);
+        return qmi_helpers_string_utf8_from_ucs2le ((const guint8 *)array->data, array->len);
     default:
         return NULL;
     }
