@@ -756,4 +756,138 @@ typedef enum { /*< since=1.26 >*/
     QMI_VOICE_CALL_CONTROL_SUPPLEMENTARY_SERVICE_TYPE_USSD              = 0x07,
 } QmiVoiceCallControlSupplementaryServiceType;
 
+/**
+ * QmiVoiceSupplementaryServiceType:
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_RELEASE_HELD_OR_WAITING: Release held or waiting call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_RELEASE_ACTIVE_ACCEPT_HELD_OR_WAITING: Release active call and accept held or waiting call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_HOLD_ACTIVE_ACCEPT_WAITING_OR_HELD: Hold active call and accept held or waiting call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_HOLD_ALL_EXCEPT_SPECIFIED_CALL: Hold all calls except specified call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_MAKE_CONFERENCE_CALL: Create conference call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_EXPLICIT_CALL_TRANSFER: Explicit call transfer.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_CCBS_ACTIVATION: Activate completion of calls to busy subscriber.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_END_ALL_CALLS: End all calls.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_RELEASE_SPECIFIED_CALL: Release a specified call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_LOCAL_HOLD: Put all active calls to hold.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_LOCAL_UNHOLD: Unhold all held calls.
+ *
+ * Supplementary service type during call.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_RELEASE_HELD_OR_WAITING               = 0x01,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_RELEASE_ACTIVE_ACCEPT_HELD_OR_WAITING = 0x02,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_HOLD_ACTIVE_ACCEPT_WAITING_OR_HELD    = 0x03,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_HOLD_ALL_EXCEPT_SPECIFIED_CALL        = 0x04,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_MAKE_CONFERENCE_CALL                  = 0x05,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_EXPLICIT_CALL_TRANSFER                = 0x06,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_CCBS_ACTIVATION                       = 0x07,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_END_ALL_CALLS                         = 0x08,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_RELEASE_SPECIFIED_CALL                = 0x09,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_LOCAL_HOLD                            = 0x0A,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_TYPE_LOCAL_UNHOLD                          = 0x0B,
+} QmiVoiceSupplementaryServiceType;
+
+/**
+ * QmiVoiceSupplementaryServiceNotificationType:
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALL_IS_FORWARDED: Outgoing call is forward.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALL_IS_WAITING: Outgoing call is waiting.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CUG_CALL: Outgoing CUG call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALLS_BARRED: All outgoing calls are barred.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALL_IS_DEFLECTED: Outgoing call is deflected.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CUG_CALL: Incoming CUG call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CALLS_BARRED: All incoming calls are barred.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_FORWARDED_CALL: Incoming forwarded call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_DEFLECTED_CALL: Incoming deflected call.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CALL_IS_FORWARDED: Incoming call is forwarded.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_UNCONDITIONAL_CALL_FORWARD_ACTIVE: Unconditional call forward is active.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CONDITIONAL_CALL_FORWARD_ACTIVE: Conditional call forward is active.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CLIR_SUPPRESSION_REJECTED: CLIR suppression is rejected.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CALL_IS_ON_HOLD: Call is on hold.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CALL_IS_RETRIEVED: Call is retrieved.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CALL_IS_IN_MULTIPARTY: Call is in multiparty.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CALL_IS_ECT: Incoming call is ECT.
+ *
+ * Supplementary service notification type.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALL_IS_FORWARDED        = 0x01,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALL_IS_WAITING          = 0x02,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CUG_CALL                 = 0x03,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALLS_BARRED             = 0x04,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_OUTGOING_CALL_IS_DEFLECTED        = 0x05,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CUG_CALL                 = 0x06,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CALLS_BARRED             = 0x07,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_FORWARDED_CALL           = 0x08,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_DEFLECTED_CALL           = 0x09,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CALL_IS_FORWARDED        = 0x0A,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_UNCONDITIONAL_CALL_FORWARD_ACTIVE = 0x0B,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CONDITIONAL_CALL_FORWARD_ACTIVE   = 0x0C,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CLIR_SUPPRESSION_REJECTED         = 0x0D,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CALL_IS_ON_HOLD                   = 0x0E,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CALL_IS_RETRIEVED                 = 0x0F,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_CALL_IS_IN_MULTIPARTY             = 0x10,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_NOTIFICATION_TYPE_INCOMING_CALL_IS_ECT              = 0x11,
+} QmiVoiceSupplementaryServiceNotificationType;
+
+/**
+ * QmiVoiceSupplementaryServiceAction:
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_ACTIVATE: Activate supplementary service.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_DEACTIVATE: De-activate supplementary service.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_REGISTER: Register supplementary service.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_ERASE: Erase/Un-register supplementary service.
+ *
+ * Supplementary service action.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_ACTIVATE   = 0x01,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_DEACTIVATE = 0x02,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_REGISTER   = 0x03,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_ACTION_ERASE      = 0x04,
+} QmiVoiceSupplementaryServiceAction;
+
+/**
+ * QmiVoiceSupplementaryServiceReason:
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_UNCONDITIONAL: Unconditional call forward.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_MOBILE_BUSY: Forward when mobile is busy.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_NO_REPLY: Forward when no reply.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_UNREACHABLE: Forward when call is unreachable.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_ALL: Forward all calls.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_ALL_CONDITIONAL: Forward all calls conditionally.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_ALL_OUTGOING: All outgoing.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_OUTGOING_INTERNAL: Outgoing Internal.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_OUTGOING_INTERNAL_EXTERNAL_TO_HOME: Outgoing internal/external to home.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_ALL_INCOMING: All incoming.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_INCOMING_ROAMING: Roaming incoming.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_BAR_ALL: All calls are barred.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_BAR_ALL_OUTGOING: All outgoing calls are barred.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_BAR_ALL_INCOMING: All incoming calls are barred.
+ * @QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_CALL_WAITING: Call waiting.
+ *
+ * Supplementary service reason.
+ *
+ * Since: 1.30
+ */
+typedef enum { /*< since=1.30 >*/
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_UNCONDITIONAL              = 0x01,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_MOBILE_BUSY                = 0x02,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_NO_REPLY                   = 0x03,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_UNREACHABLE                = 0x04,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_ALL                        = 0x05,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_FORWARD_ALL_CONDITIONAL            = 0x06,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_ALL_OUTGOING                       = 0x07,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_OUTGOING_INTERNAL                  = 0x08,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_OUTGOING_INTERNAL_EXTERNAL_TO_HOME = 0x09,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_ALL_INCOMING                       = 0x0A,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_INCOMING_ROAMING                   = 0x0B,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_BAR_ALL                            = 0x0C,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_BAR_ALL_OUTGOING                   = 0x0D,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_BAR_ALL_INCOMING                   = 0x0E,
+    QMI_VOICE_SUPPLEMENTARY_SERVICE_REASON_CALL_WAITING                       = 0x0F,
+} QmiVoiceSupplementaryServiceReason;
+
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_VOICE_H_ */
