@@ -78,8 +78,10 @@
  * @QMI_DMS_BAND_CAPABILITY_WCDMA_1500: WCDMA 1500 band.
  *
  * Frequency band capabilities.
+ *
+ * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_BAND_CAPABILITY_BC_0_A_SYSTEM    = 1 << 0,
     QMI_DMS_BAND_CAPABILITY_BC_0_B_SYSTEM    = 1 << 1,
     QMI_DMS_BAND_CAPABILITY_BC_1_ALL_BLOCKS  = 1 << 2,
@@ -126,12 +128,6 @@ typedef enum {
     /* Bits 62-63 reserved */
 } QmiDmsBandCapability;
 
-/**
- * qmi_dms_band_capability_build_string_from_mask:
- *
- * Since: 1.0
- */
-
 /**
  * QmiDmsLteBandCapability:
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_1: LTE EUTRAN Band 1
@@ -175,8 +171,10 @@ typedef enum {
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_43: LTE EUTRAN Band 43.
  *
  * LTE-specific Frequency bands.
+ *
+ * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_1  = 1 << 0,
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_2  = 1 << 1,
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_3  = 1 << 2,
@@ -221,10 +219,4 @@ typedef enum {
     /* Bit 43-64 reserved */
 } QmiDmsLteBandCapability;
 
-/**
- * qmi_dms_lte_band_capability_build_string_from_mask:
- *
- * Since: 1.0
- */
-
 #endif /* _LIBQMI_GLIB_QMI_FLAGS64_DMS_H_ */
