@@ -22,10 +22,18 @@
 #define VIRTUAL_SOCKET_PATH "virtual-socket-path"
 
 static const QmiService services [] = {
+#if defined HAVE_QMI_SERVICE_DMS
     QMI_SERVICE_DMS,
+#endif
+#if defined HAVE_QMI_SERVICE_NAS
     QMI_SERVICE_NAS,
+#endif
+#if defined HAVE_QMI_SERVICE_WDS
     QMI_SERVICE_WDS,
+#endif
+#if defined HAVE_QMI_SERVICE_PDS
     QMI_SERVICE_PDS
+#endif
 };
 
 static void
@@ -229,6 +237,20 @@ device_release_client_ready (QmiDevice    *device,
     test_fixture_loop_stop (fixture);
 }
 
+static void
+device_close_ready (QmiDevice    *device,
+                    GAsyncResult *res,
+                    TestFixture  *fixture)
+{
+    GError *error = NULL;
+    gboolean st;
+
+    st = qmi_device_close_finish (device, res, &error);
+    g_assert_no_error (error);
+    g_assert (st);
+    test_fixture_loop_stop (fixture);
+}
+
 void
 test_fixture_teardown (TestFixture *fixture)
 {
@@ -295,12 +317,12 @@ test_fixture_teardown (TestFixture *fixture)
     }
 
     if (fixture->device) {
-        GError *error = NULL;
-        gboolean ret;
+        qmi_device_close_async (fixture->device, 10, NULL,
+                                (GAsyncReadyCallback) device_close_ready,
+                                fixture);
+
+        test_fixture_loop_run (fixture);
 
-        ret = qmi_device_close (fixture->device, &error);
-        g_assert_no_error (error);
-        g_assert (ret);
         g_object_unref (fixture->device);
     }
 
